#
# spec file for package python-pymarc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pymarc
Version:        5.2.3
Release:        1.3
Summary:        MARC bibliographic data manipulation module
License:        BSD-2-Clause
URL:            https://gitlab.com/pymarc/pymarc
Source:         https://files.pythonhosted.org/packages/source/p/pymarc/pymarc-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytest
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
pymarc is a Python library for working with bibliographic data
encoded in MARC21. It provides an API for reading, writing and
modifying MARC records. It was originally designed to be an emergency
eject seat for getting data assets out of MARC and into some kind of
saner representation.

%prep
%setup -q -n pymarc-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pymarc
%{python_sitelib}/pymarc-%{version}.dist-info

%changelog
* Thu Nov 14 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 5.3.3
  * A small bugfix release to ensure logging uses a namespace
    rather than the root logger !213. This should allow pymarc
    log messages to be more legible in applications that use it.
  * On the development side, the setup.py was replaced with
    pyproject.toml, and the CI build was switched to use uv
    to manage the virtual environment.
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Limit Python files matched in %%files section
- Use Python 3.11 on SLE-15 by default
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 5.2.2:
  * Leader object is correctly initialized when the force_utf8
    option is being used
  * fix for the behavior of Field.indicators to preserve backwards
    compatibility when setting the indicators to a list or tuple
    of two items
  * Added MARCMakerReader class for reading MARC data from a
    textual representation of a MARC record, expanding the previous
    capability of pymarc to output MARC records in this format
  * The Leader class is now automatically initialized for easier
    access and updates
  * Created Indicators type to limit indicator length and improve
    handling
  * Improved documentation of record status
  * Field objects now throw a KeyError exception if you try to
    set a subfield since they don't contain subfields
  * Fixed issue with iterating over fields and subfields
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 5.1.2:
  * minor changes
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 5.1.1:
  * py.typed marker
* Sat Dec  9 2023 Dirk Müller <dmueller@suse.com>
- update to 5.1.0:
  * Formatting fixes
  * Fstring conversion
  * Fixed: Normalize JSONHandler class name
  * Adds a guardrail for handling malformed MARC8 data in
    multibytes instead of raising exception
- use packaged LICENSE
* Tue Apr 11 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.2.2:
  * Bugfix for python_requires in setup.py.
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 4.2.1
  * Bugfix for Field.delete_subfield() for situations when a subfield value is present with the name of the subfield that you want to delete.
  * Updated README to point to ReadTheDocs documentation.
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 4.2.0
  * Merge branch 'linked_fields' into 'main'
  * Adds a method to get linked (880) fields
  * fix default branch
  * ran black .
  * Merge branch 'exception-typo' into 'master'
  * removed innaccurate text fixes #178
  * FatalErorReader typo
  * fixes #179
  * Merge branch 'issnl' into 'master'
  * ISSN-L
  * Ignore venv
  * Merge branch 'master' into 'master'
  * Fix issue #176 - allow writing records parsed with to_unicode=False
  * latest committers
  * merged
  * Merge branch 'fontanka16-master-patch-75274' into 'master'
  * Merge branch 'readme-irc' into 'master'
  * Fix pep8 violation in pymarc.Record.sudoc docstring
  * (readme) freenode --> libera
  * Merge branch 'wrecksdart-master-patch-69704' into 'master'
  * Updated docstring and informational URL for sudoc
  * Update CONTRIBUTING.md to reflect move to Gitlab
  * Add typing for Regex pattern
  * Fixed: Remove unused import
  * Formatting: Changed by `black`
  * New: Type hints on record.py
  * hopefully fixes #171
  * Field.subfields_as_dict always returns value lists
  * Repeatable subfields
- Update to 4.1.0
  * adding 3.9
  * pypy
  * appease mypy
  * small change for black
  * Merge branch 'master' into 'master'
  * Add a convenient function for getting subfields as a dictionary
  * Merge branch 'fix-typehints-in-marc8.py' into 'master'
  * make flake8 happy
  * Merge branch 'patch-1' into 'master'
  * make black happy
  * Make record.fields a list, not an iterator in map_marc8_record
  * Remove unused imports
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 4.0.0
  * Drop Python2
  * Support Python3.8
  * Add type hints
  * Many fixes
- Drop patch python38.patch
* Fri Dec  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix building with python 3.8:
  * python38.patch
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Replace summary copy by
  upstream's description.
* Wed Jul 31 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v3.1.13
